# eric7.QtHelpInterface.QtHelpDocumentationSettingsWidget

Module implementing a widget to manage the QtHelp documentation settings.

### Global Attributes

None

### Classes

QtHelpDocumentationSettingsWidget | Class implementing a widget to manage the QtHelp documentation settings.

### Functions

None

## QtHelpDocumentationSettingsWidget

Class implementing a widget to manage the QtHelp documentation settings.

### Signals

documentationSettingsChanged(settings)
  emitted to signal a change of the documentation configuration

### Derived from

QWidget, Ui_QtHelpDocumentationSettingsWidget

### Class Attributes

None

### Class Methods

None

### Methods

QtHelpDocumentationSettingsWidget | Constructor
__applyDocumentsListFilter | Private slot to apply the current documents filter.
__registerDocumentation | Private method to register a given list of documentations.
documentationSettings | Public method to get the reference to the QtHelp documentation configuration object.
on_addDocumentsButton_clicked | Private slot to add QtHelp documents to the help database.
on_addPluginButton_clicked | Private slot to add QtHelp documents provided by plug-ins to the help database.
on_documentsList_itemSelectionChanged | Private slot handling a change of the documents selection.
on_filterEdit_textChanged | Private slot to react on changes of the document filter text.
on_managePluginButton_clicked | Private slot to manage the QtHelp documents provided by plug-ins.
on_removeDocumentsButton_clicked | Private slot to remove a document from the help database.
setDocumentationSettings | Public method to set the reference to the QtHelp documentation configuration object.

### Static Methods

None

#### QtHelpDocumentationSettingsWidget (Constructor)

QtHelpDocumentationSettingsWidget(parent=None)

Constructor

parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### QtHelpDocumentationSettingsWidget.__applyDocumentsListFilter

__applyDocumentsListFilter()

Private slot to apply the current documents filter.

#### QtHelpDocumentationSettingsWidget.__registerDocumentation

__registerDocumentation(filenames)

Private method to register a given list of documentations.

filenames (list of str)
  list of documentation files to be registered

#### QtHelpDocumentationSettingsWidget.documentationSettings

documentationSettings()

Public method to get the reference to the QtHelp documentation configuration object.

Return:
  reference to the created QtHelpDocumentationSettings object

Return Type:
  QtHelpDocumentationSettings

#### QtHelpDocumentationSettingsWidget.on_addDocumentsButton_clicked

on_addDocumentsButton_clicked()

Private slot to add QtHelp documents to the help database.

#### QtHelpDocumentationSettingsWidget.on_addPluginButton_clicked

on_addPluginButton_clicked()

Private slot to add QtHelp documents provided by plug-ins to the help database.

#### QtHelpDocumentationSettingsWidget.on_documentsList_itemSelectionChanged

on_documentsList_itemSelectionChanged()

Private slot handling a change of the documents selection.

#### QtHelpDocumentationSettingsWidget.on_filterEdit_textChanged

on_filterEdit_textChanged(txt)

Private slot to react on changes of the document filter text.

txt (str)
  current entry of the filter

#### QtHelpDocumentationSettingsWidget.on_managePluginButton_clicked

on_managePluginButton_clicked()

Private slot to manage the QtHelp documents provided by plug-ins.

#### QtHelpDocumentationSettingsWidget.on_removeDocumentsButton_clicked

on_removeDocumentsButton_clicked()

Private slot to remove a document from the help database.

#### QtHelpDocumentationSettingsWidget.setDocumentationSettings

setDocumentationSettings(settings)

Public method to set the reference to the QtHelp documentation configuration object.

settings (QtHelpDocumentationSettings)
  reference to the created QtHelpDocumentationSettings object

Up